package com.uoc.cclavero.freeauthenticator.activities;

import android.content.Intent;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import com.uoc.cclavero.freeauthenticator.R;
import com.uoc.cclavero.freeauthenticator.helpers.Base32String;

public class AddKeyKeyboardActivity extends AppCompatActivity {

    private static final int MIN_KEY_BYTES = 10;
    public static final String DESCRIPTION = "DESCRIPTION";
    public static final String KEY = "KEY";
    Button addButton;
    EditText descriptionTextView, privateKeyTextView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_add_key_keyboard);

        descriptionTextView = (EditText) findViewById(R.id.service_description);
        privateKeyTextView = (EditText) findViewById(R.id.private_key_value);

        addButton = (Button) findViewById(R.id.add_button);
        addButton.setOnClickListener( new View.OnClickListener() {

            @Override
            public void onClick(View v) {
                if (!isValidDescription(descriptionTextView.getText().toString())) {
                    descriptionTextView.setError(getString(R.string.message_error_description_empty));
                    return;
                }else if(!isValidPrivateKey(privateKeyTextView.getText().toString())){
                    privateKeyTextView.setError(getString(R.string.message_error_private_key_too_short));
                    return;
                } else {
                    descriptionTextView.setError(null);
                    privateKeyTextView.setError(null);
                    saveKey();
                }
            }
        });

        setTitle(R.string.title_add_key_keyboard_activity);
    }

    private void saveKey() {
        String description = descriptionTextView.getText().toString();
        String privateKey = sanitizePrivateKey(privateKeyTextView.getText().toString());

        Intent replyIntent = new Intent();
        replyIntent.putExtra(DESCRIPTION, description);
        replyIntent.putExtra(KEY, privateKey.toUpperCase());

        setResult(RESULT_OK, replyIntent);
        finish();
    }

    public static boolean isValidDescription(String description) {
        if(description.trim().length() == 0) {
            return false;
        }

        return true;
    }

    /***
     * Sanitizes the user entered keys as per RFC4226 - Section: Extensions E2
     * @return string
     */
    public static String sanitizePrivateKey(String privateKey){
        return privateKey.replace('1', 'I').replace('0', 'O');
    }

    public static boolean isValidPrivateKey(String privateKey) {
        String enteredKey = sanitizePrivateKey(privateKey);
        try {
            byte[] decoded = Base32String.decode(enteredKey);
            if (decoded.length < MIN_KEY_BYTES) {
                return false;
            } else {
                return true;
            }
        } catch (Exception e) {
            return false;
        }
    }
}
