package com.uoc.cclavero.freeauthenticator.activities;

import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.ViewGroup;
import android.widget.Toast;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.Result;

import me.dm7.barcodescanner.zxing.ZXingScannerView;

import com.uoc.cclavero.freeauthenticator.R;

import java.util.Collections;
import java.util.List;

public class AddKeyQRActivity extends AppCompatActivity implements ZXingScannerView.ResultHandler {
    public static final String DESCRIPTION = "DESCRIPTION";
    public static final String KEY = "KEY";
    private ZXingScannerView scannerView;
    private final List<BarcodeFormat> formats = Collections.singletonList(BarcodeFormat.QR_CODE);
    private String description, privateKey;

    @Override
    public void onCreate(Bundle state) {
        super.onCreate(state);
        setContentView(R.layout.activity_scan);

        ViewGroup contentFrame = (ViewGroup) findViewById(R.id.content_frame);
        scannerView = new ZXingScannerView(this);
        contentFrame.addView(scannerView);
        scannerView.setLaserEnabled(false);
        scannerView.setSquareViewFinder(true);
        scannerView.setFormats(formats);

        setTitle(R.string.title_new_key_qr_activity);
    }

    @Override
    public void onResume() {
        super.onResume();
        scannerView.setResultHandler(this);
        scannerView.startCamera();
    }

    @Override
    public void onPause() {
        super.onPause();
        scannerView.stopCamera();
    }

    @Override
    public void handleResult(Result rawResult) {

        if(this.validateQRCode(rawResult.getText())) {
            Intent replyIntent = new Intent();
            replyIntent.putExtra(KEY, this.privateKey);
            replyIntent.putExtra(DESCRIPTION, this.description);
            setResult(RESULT_OK, replyIntent);
            finish();
        }

        scannerView.setResultHandler(this);
        scannerView.startCamera();
    }

    private boolean validateQRCode(String qr_content){
        Uri uri = Uri.parse(qr_content);

        try{
            if(!uri.getScheme().equals("otpauth")){
                throw new Exception();
            }

            if(!uri.getHost().equals("totp")){
                throw new Exception();
            }

            String secret = uri.getQueryParameter("secret");
            String label = uri.getPath().substring(1);
            String issuer = uri.getQueryParameter("issuer");

            if(issuer != null){
                label = issuer +" - "+label;
            }

            this.description = label;
            this.privateKey = secret.toUpperCase();

            return true;
        }catch(Exception e){
            Toast.makeText(this, R.string.message_error_code_not_valid, Toast.LENGTH_SHORT).show();
            return false;
        }
    }
}
