package com.uoc.cclavero.freeauthenticator.activities;

import android.content.Context;
import android.content.Intent;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.uoc.cclavero.freeauthenticator.R;

public class CreateBackupActivity extends AppCompatActivity {

    public static final String DESTINATION_STORAGE = "DESTINATION_STORAGE";
    public static final String ENCRYPTION_KEY = "ENCRYPTION_KEY";
    public static final int MIN_PASSWORD_LENGHT = 4;

    private LinearLayout fileLocationLinearLayout;
    private TextView backupDestinationTextView;
    private EditText passwordEditTextView;
    private ImageView localStorageImageView, googleDriveStorageImageView;
    private Button createBackupButton;
    private Context context;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_create_backup);
        context = this.getApplicationContext();
        setTitle(R.string.title_create_backup_activity);

        backupDestinationTextView = (TextView) findViewById(R.id.backup_destination);
        passwordEditTextView = (EditText) findViewById(R.id.encryption_key_value);
        localStorageImageView = (ImageView) findViewById(R.id.local_storage_button);
        googleDriveStorageImageView = (ImageView) findViewById(R.id.google_drive_storage_button);
        fileLocationLinearLayout = (LinearLayout) findViewById(R.id.folder_picker);
        createBackupButton = (Button) findViewById(R.id.create_backup_button);


        localStorageImageView.setOnClickListener( new View.OnClickListener() {

            @Override
            public void onClick(View v) {
                v.setActivated(!v.isActivated());
                googleDriveStorageImageView.setActivated(false);
                fileLocationLinearLayout.setVisibility(View.VISIBLE);
                backupDestinationTextView.setText(R.string.message_backup_stored_inside_documents_folder);
            }
        });

        googleDriveStorageImageView.setOnClickListener( new View.OnClickListener() {

            @Override
            public void onClick(View v) {
                v.setActivated(!v.isActivated());
                localStorageImageView.setActivated(false);
                fileLocationLinearLayout.setVisibility(View.VISIBLE);
                backupDestinationTextView.setText(R.string.message_backup_stored_inside_app_folder);
            }
        });

        createBackupButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if(checkDetails()) {
                    if(!checkPassword(passwordEditTextView.getText().toString())) {
                        passwordEditTextView.setError(getString(R.string.message_error_no_password_entered_create_backup));
                        passwordEditTextView.requestFocus();
                    }
                    else {
                        String destinationStorage = "";
                        if(localStorageImageView.isActivated())
                            destinationStorage = "local";
                        if(googleDriveStorageImageView.isActivated())
                            destinationStorage = "google_drive";

                        storeBackup(destinationStorage, passwordEditTextView.getText().toString());
                    }
                }
                else
                    Toast.makeText(context,"Please select the storage", Toast.LENGTH_SHORT).show();
            }
        });
    }

    public static boolean checkPassword(String password) {
        if(password.trim().length() < CreateBackupActivity.MIN_PASSWORD_LENGHT) {
            return false;
        }

        return true;
    }

    private boolean checkDetails() {
        return (localStorageImageView.isActivated() || googleDriveStorageImageView.isActivated());
    }

    private void storeBackup(String destinationStorage, String password){
        Intent replyIntent = new Intent();

        switch (destinationStorage) {
            case "local":
            case "google_drive":
                break;
            default:
                Toast.makeText(context,R.string.error_during_backup_creation, Toast.LENGTH_LONG).show();
                setResult(RESULT_CANCELED, replyIntent);
                finish();
                return;
        }

        replyIntent.putExtra(DESTINATION_STORAGE, destinationStorage);
        replyIntent.putExtra(ENCRYPTION_KEY, password.trim());

        setResult(RESULT_OK, replyIntent);
        finish();
    }

    @Override
    public void finish() {
        super.finish();
        overridePendingTransition(R.anim.fadein, R.anim.fadeout);
    }
}
