package com.uoc.cclavero.freeauthenticator.activities;

import android.content.Intent;
import android.os.Bundle;

import com.google.android.gms.drive.DriveContents;
import com.google.android.gms.drive.DriveFolder;
import com.google.android.gms.drive.MetadataChangeSet;
import com.google.android.gms.tasks.Task;
import com.google.android.gms.tasks.Tasks;
import com.uoc.cclavero.freeauthenticator.R;
import com.uoc.cclavero.freeauthenticator.helpers.GoogleDriveHelper;

import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;

public class GoogleDriveCreateFileActivity extends GoogleDriveHelper {
    public static final String FILENAME = "FILENAME";
    public static final String FILE_CONTENT = "FILE_CONTENT";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_accessing_google_drive);
    }

    @Override
    protected void onDriveClientReady() {
        createFile();
    }

    private void createFile() {
        Intent intent = getIntent();

        String filename = intent.getStringExtra(FILENAME);
        String file_content = intent.getStringExtra(FILE_CONTENT);

        final Task<DriveFolder> rootFolder = getDriveResourceClient().getRootFolder();
        final Task<DriveContents> createContentsTask = getDriveResourceClient().createContents();
        Tasks.whenAll(rootFolder, createContentsTask)
                .continueWithTask(task -> {
                    DriveFolder parent = rootFolder.getResult();
                    DriveContents contents = createContentsTask.getResult();
                    OutputStream outputStream = contents.getOutputStream();
                    try (Writer writer = new OutputStreamWriter(outputStream)) {
                        writer.write(file_content);
                    }

                    MetadataChangeSet changeSet = new MetadataChangeSet.Builder()
                            .setTitle(filename)
                            .setMimeType("text/plain")
                            .setStarred(true)
                            .build();

                    return getDriveResourceClient().createFile(parent, changeSet, contents);
                })
                .addOnSuccessListener(this,
                        driveFile -> {
                            showMessage(getString(R.string.backup_file_created));
                            finish();
                        })
                .addOnFailureListener(this, e -> {
                    showMessage(getString(R.string.backup_file_create_error));
                    finish();
                });
    }
}