package com.uoc.cclavero.freeauthenticator.activities;

import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.widget.Button;
import android.widget.EditText;

import com.uoc.cclavero.freeauthenticator.R;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Objects;

public class RestoreBackupActivity extends AppCompatActivity {

    public static final String FILE_CONTENT = "FILE_CONTENT";
    public static final String ENCRYPTION_KEY = "ENCRYPTION_KEY";

    private static final int READ_REQUEST_CODE = 1;

    private EditText passwordEditTextView;
    private String fileContent;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_restore_backup);
        setTitle(R.string.title_restore_backup_activity);

        passwordEditTextView = (EditText) findViewById(R.id.encryption_key_value);
        Button pickFileButton = (Button) findViewById(R.id.folder_picker_button);


        pickFileButton.setOnClickListener(v -> {
            if(CreateBackupActivity.checkPassword(passwordEditTextView.getText().toString())) {
                Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
                intent.addCategory(Intent.CATEGORY_OPENABLE);
                intent.setType("text/plain");
                startActivityForResult(intent, READ_REQUEST_CODE);
            }
            else {
                passwordEditTextView.setError(getString(R.string.message_error_no_password_entered_restore_backup));
                passwordEditTextView.requestFocus();
            }
        });
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent resultData) {
        if (requestCode == READ_REQUEST_CODE && resultCode == Activity.RESULT_OK && resultData != null) {
            Uri uri = resultData.getData();
            fileContent = readTextFile(uri);
            restoreBackup();
        }
    }

    private String readTextFile(Uri uri){
        BufferedReader reader = null;
        StringBuilder builder = new StringBuilder();
        try {
            reader = new BufferedReader(new InputStreamReader(Objects.requireNonNull(getContentResolver().openInputStream(uri))));
            String line;

            while ((line = reader.readLine()) != null) {
                builder.append(line);
            }

        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (reader != null){
                try {
                    reader.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return builder.toString();
    }


    private void restoreBackup(){
        Intent replyIntent = new Intent();

        replyIntent.putExtra(FILE_CONTENT, fileContent);
        replyIntent.putExtra(ENCRYPTION_KEY, passwordEditTextView.getText().toString().trim());

        setResult(RESULT_OK, replyIntent);
        finish();
    }

    @Override
    public void finish() {
        super.finish();
        overridePendingTransition(R.anim.fadein, R.anim.fadeout);
    }
}
