package com.uoc.cclavero.freeauthenticator.adapters;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.v7.widget.PopupMenu;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.uoc.cclavero.freeauthenticator.R;
import com.uoc.cclavero.freeauthenticator.entities.Key;

import java.util.List;

public class KeyListAdapter extends RecyclerView.Adapter<KeyListAdapter.KeyViewHolder> {

    private Context context;
    private OnItemMenuClickListener listener;
    private int countDown = -1;

    class KeyViewHolder extends RecyclerView.ViewHolder {
        private final TextView codeItemTextView, descriptionItemTextView, expirationCounterTextView;
        private final ImageView buttonOptionImageView;

        private KeyViewHolder(View itemView) {
            super(itemView);
            codeItemTextView = itemView.findViewById(R.id.code);
            descriptionItemTextView = itemView.findViewById(R.id.description);
            expirationCounterTextView = itemView.findViewById(R.id.expiration_counter);
            buttonOptionImageView = itemView.findViewById(R.id.item_menu);
        }
    }

    private final LayoutInflater inflater;
    private List<Key> keys; // Cached copy of keys

    public KeyListAdapter(Context context) {
        inflater = LayoutInflater.from(context);
        this.context = context;

    }

    @NonNull
    @Override
    public KeyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = inflater.inflate(R.layout.key_item, parent, false);
        return new KeyViewHolder(itemView);
    }

    @Override
    public void onBindViewHolder(@NonNull final KeyViewHolder holder, int position) {
        final Key currentKey = keys.get(position);
        holder.codeItemTextView.setText(currentKey.getToken());
        holder.descriptionItemTextView.setText(currentKey.getDescription());

        if(this.countDown == -1 )
            holder.expirationCounterTextView.setText("");
        else
            holder.expirationCounterTextView.setText(String.format("%ss", String.valueOf(this.countDown)));

        if (this.countDown <= 10 && this.countDown > 5) {
            holder.codeItemTextView.setTextColor(context.getResources().getColor(R.color.colorWarning));
        }else if (this.countDown <= 5 && this.countDown > -1) {
            holder.codeItemTextView.setTextColor(context.getResources().getColor(R.color.colorDanger));
        }else
            holder.codeItemTextView.setTextColor(context.getResources().getColor(R.color.colorPrimary));

        holder.buttonOptionImageView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
            PopupMenu popup = new PopupMenu(context, holder.buttonOptionImageView);
            popup.inflate(R.menu.menu_list_element);
            popup.setOnMenuItemClickListener(new PopupMenu.OnMenuItemClickListener() {
                @Override
                public boolean onMenuItemClick(MenuItem item) {
                    switch (item.getItemId()) {
                        case R.id.action_edit:
                            if(listener != null)
                                listener.onItemMenuClick(currentKey, false);
                            return true;
                        case R.id.action_delete:
                            if(listener != null)
                                listener.onItemMenuClick(currentKey, true);
                            return true;
                        default:
                            return false;
                    }
                }
            });
            popup.show();
            }
        });
    }

    public void setKeys(List<Key> keys){
        this.keys = keys;
        notifyDataSetChanged();
    }

    @Override
    public int getItemCount() {
        if (keys != null)
            return keys.size();
        else return 0;
    }

    public Key getKeyAt(int position){
        return keys.get(position);
    }

    public interface OnItemMenuClickListener {
        void onItemMenuClick(Key key, boolean delete);
    }

    public void setOnItemClickListener(OnItemMenuClickListener listener) {
        this.listener = listener;
    }

    public void setCountDown(int value){ this.countDown = value; }
}
