package com.uoc.cclavero.freeauthenticator.data;

import android.app.Application;
import android.arch.lifecycle.LiveData;
import android.os.AsyncTask;

import com.uoc.cclavero.freeauthenticator.entities.Key;
import com.uoc.cclavero.freeauthenticator.interfaces.KeyDAO;

import java.util.List;

public class KeyRepository {

    private KeyDAO keyDao;
    private LiveData<List<Key>> allKeys;

    public KeyRepository(Application application) {
        KeyRoomDatabase db = KeyRoomDatabase.getDatabase(application);
        keyDao = db.keyDAO();
        allKeys = keyDao.getAllKeys();
    }

    LiveData<List<Key>> getAllKeys() {
        return allKeys;
    }

    public void insert (Key key) {
        new InsertAsyncTask(keyDao).execute(key);
    }

    public void update (Key key) {
        new UpdateAsyncTask(keyDao).execute(key);
    }

    public void delete (Key key) {
        new DeleteAsyncTask(keyDao).execute(key);
    }

    private static class InsertAsyncTask extends AsyncTask<Key, Void, Void> {

        private KeyDAO asyncTaskDao;

        private InsertAsyncTask(KeyDAO dao) {
            asyncTaskDao = dao;
        }

        @Override
        protected Void doInBackground(final Key... keys) {
            asyncTaskDao.insert(keys[0]);
            return null;
        }
    }

    private static class UpdateAsyncTask extends AsyncTask<Key, Void, Void> {

        private KeyDAO asyncTaskDao;

        private UpdateAsyncTask(KeyDAO dao) {
            asyncTaskDao = dao;
        }

        @Override
        protected Void doInBackground(final Key... keys) {
            asyncTaskDao.update(keys[0]);
            return null;
        }
    }

    private static class DeleteAsyncTask extends AsyncTask<Key, Void, Void> {

        private KeyDAO asyncTaskDao;

        private DeleteAsyncTask(KeyDAO dao) {
            asyncTaskDao = dao;
        }

        @Override
        protected Void doInBackground(final Key... keys) {
            asyncTaskDao.delete(keys[0]);
            return null;
        }
    }
}
